from itchio.User import User


class DownloadKey:
    def __init__(
            self,
            id: int,
            created_at: str,
            downloads: int,
            key: str,
            game_id: int,
            owner: User) -> None:

        self.id = id
        self.created_at = created_at
        self.downloads = downloads
        self.key = key
        self.game_id = game_id
        self.owner = owner

    @classmethod
    def parse_from_dict(cls, data: dict):
        return cls(
            id=data["id"],
            created_at=data["created_at"],
            downloads=data["downloads"],
            key=data["key"],
            game_id=data["game_id"],
            owner=User.parse_from_dict(data["owner"])
        )



from typing import Union


class Purchase:
    def __init__(
            self,
            donation: Union[bool, None],
            id: int,
            email: str,
            created_at: str,
            source: str,
            currency: str,
            price: str,
            sale_rate: int,
            game_id: int) -> None:

        self.donation = donation
        self.id = id
        self.email = email
        self.created_at = created_at
        self.source = source
        self.currency = currency
        self.price = price
        self.sale_rate = sale_rate
        self.game_id = game_id

    @classmethod
    def parse_from_dict(cls, data: dict):
        return cls(
            donation=data["donation"],
            id=data["id"],
            email=data["email"],
            created_at=data["created_at"],
            source=data["source"],
            currency=data["currency"],
            price=data["price"],
            sale_rate=data["sale_rate"],
            game_id=data["game_id"]
        )



class Earnings:
    def __init__(
            self,
            currency: str,
            amount_formatted: str,
            amount: int):

        self.currency = currency
        self.amount_formatted = amount_formatted
        self.amount = amount

    @classmethod
    def parse_from_dict(cls, data: dict):
        return cls(
            currency=data["currency"],
            amount_formatted=data["amount_formatted"],
            amount=data["amount"]
        )
